==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/sv/pub.php <==
<?php
regGS("trial subscription", "provprenumeration");
regGS("paid subscription", "betald prenumeration");
regGS("time units", "tidsenheter");
regGS("one language", "ett språk");
regGS("all languages", "alla språk");
regGS("Trial subscriptions", "Provprenumerationer");
regGS("Time unit cost per one section", "Tidsenhetskostnad per sektion");
regGS("Paid subscriptions", "Betalda prenumerationer");
regGS("Default time period", "Grundtidsperiod");
regGS("Publication List", "Publikationslista");
regGS("Go To Issues", "Gå till utgåvor");
regGS("Name<BR><SMALL>(click to see issues)</SMALL>", "Namn<BR><SMALL>(klicka för att se utgåvor)</SMALL>");
regGS("Delete publication $1", "Radera publikation $1");
regGS("No publications.", "Inga publikationer.");
regGS("Default Site Alias", "Förvalt sajtalias");
regGS("URL Type", "URL-typ");
regGS("Country<BR><SMALL>(click to edit)</SMALL>", "Land<BR><SMALL>(klicka för att ändra)</SMALL>");
regGS("Delete alias $1", "Radera alias $1");
regGS("Configure publication", "Konfigurera publikation");
regGS("You do not have the right to edit publication information.", "Du har inte rätt att redigera publikationsinformation.");
regGS("General attributes", "Generella attribut");
regGS("Subscriptions defaults", "Prenumerationsgrundinställningar");
regGS("Countries defaults", "Landsgrundinställningar");
regGS("Changing publication information", "Ändrar publikationsinformation");
regGS("You do not have the right to change publication information.", "Du har inte rätt att ändra publikationsinformation.");
regGS("The publication information could not be updated.", "Publikationsinformationen kunde inte uppdateras.");
regGS("Please check if another publication with the same name or the same site name does not already exist.", "Var god kontrollera om en publikation med samma namn eller samma sajtnamn redan finns.");
regGS("You do not have the right to delete publications.", "Du har inte rätt att radera publikationer.");
regGS("Are you sure you want to delete the publication $1?", "Är du säker att du vill radera publikationen $1?");
regGS("Deleting publication", "Raderar publikation");
regGS("There are $1 subscription(s) left.", "Det finns $1 prenumeration(er) kvar.");
regGS("The publication $1 could not be deleted.", "Publikationen $1 kunde inte raderas.");
regGS("Adding new publication", "Lägger till ny publikation");
regGS("The publication could not be added.", "Publikationen kunde inte läggas till.");
regGS("Add new country default subscription time", "Lägg till ny landsgrundprenumerationstid.");
regGS("You do not have the right to manage publications.", "Du har inte rätt att hantera publikationer.");
regGS("Please check if another entry with the same country code exists already.", "Var god kontrollera om ett land med samma landskod redan finns.");
regGS("Adding new country default subscription time", "Lägger till ny landsgrundprenumerationstid");
regGS("You must select a country.", "Du måste välja ett land.");
regGS("The default subscription time for country $1 could not be added.", "Grundprenumerationstiden för land $1 kunde inte läggas till.");
regGS("Change subscription default time", "Ändra grundprenumerationstid");
regGS("Default subscription time for $1 changed", "Grundprenumerationstid för $1 ändrad");
regGS("Are you sure you want to delete the subscription default time for $1?", "Är du säker att du vill radera grundprenumerationstiden för $1?");
regGS("Subscription default time for $1 deleted", "Grundprenumerationstiden för $1 raderad");
regGS("Add new alias", "Lägg till nytt alias");
regGS("Alias (click to edit)", "Alias (klicka för att redigera)");
regGS("Edit aliases", "Redigera aliasar");
regGS("Publication Aliases", "Publikationsaliasar");
regGS("Adding new alias", "Lägger till nytt alias");
regGS("The site alias $1 has been added to publication $2.", "Sajtaliaset $1 har lagts till till publikationen $2.");
regGS("The site alias $1 could not be added.", "Sajtaliaset $1 kunde inte läggas till.");
regGS("Another alias with the same name exists already.", "Ett annat alias med samma namn finns redan.");
regGS("Edit alias", "Redigera alias");
regGS("Editing alias", "Redigerar alias");
regGS("The site alias for publication $1 has been modified to $2.", "Sajtaliaset för publikationen $1 har ändrats till $2.");
regGS("The site alias $1 could not be modified.", "Sajtaliaset $1 kunde inte ändras.");
regGS("Are you sure you want to delete the alias $1?", "Är du säker att du vill radera sajtaliaset $1?");
regGS("Deleting alias", "Raderar alias");
regGS("The alias $1 could not be deleted.", "Aliaset $1 kunde inte raderas.");
regGS("The alias $1 has been deleted from publication $2.", "Aliaset $1 har raderats från publikationen $2.");
regGS("$1 is the default publication alias, it can not be deleted.", "$1 är grundpublikationsaliaset, det kan inte raderas.");
regGS("You do not have the right to add publications.", "Du har inte rätt att lägga till publikationer.");
regGS("There are $1 issue(s) left.", "Det finns $1 utgåva(or) kvar.");
regGS("Select the publication", "Välj publikation");
regGS("Name<BR><SMALL>(click to select the publication)</SMALL>", "Namn<BR><SMALL>(klicka för att välja publikation)</SMALL>");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/sv/pub.php <==
<?php 
regGS("Use CAPTCHA to prevent spam?", "");
regGS("Public allowed to comment?", "");
regGS("Enable spam blocking?", "");
regGS("The subscription settings for '$1' could not be added.", "");
regGS("The publication name you specified conflicts with publication '$1'.", "");
regGS("The publication alias you specified conflicts with publication '$1'.", "");
regGS("Subscription defaults", "");
regGS("Subscription Settings by Country", "");
regGS("Set subscription settings for a country", "");
regGS("Set subscription settings by country", "");
regGS("Default time periods:", "");
regGS("Country subscription settings updated.", "");
regGS("Country subscription settings deleted.", "");
regGS("Change country subscription settings", "");
regGS("Are you sure you want to delete the subscription settings for $1?", "");
regGS("Publication updated", "Publikationen uppdaterad");
regGS("Subscriber comments moderated?", "");
regGS("Public comments moderated?", "");
regGS("Comments enabled?", "");
regGS("Comments enabled", "");
regGS("Article comments default to enabled?", "");
regGS("trial subscription", "provprenumeration");
regGS("paid subscription", "betald prenumeration");
regGS("time units", "tidsenheter");
regGS("one language", "ett språk");
regGS("all languages", "alla språk");
regGS("Trial subscriptions", "Provprenumerationer");
regGS("Time unit cost per one section", "Tidsenhetskostnad per sektion");
regGS("Paid subscriptions", "Betalda prenumerationer");
regGS("Default time period", "Grundtidsperiod");
regGS("Go To Issues", "Gå till utgåvor");
regGS("Name<BR><SMALL>(click to see issues)</SMALL>", "Namn<BR><SMALL>(klicka för att se utgåvor)</SMALL>");
regGS("Delete publication $1", "Radera publikation $1");
regGS("No publications.", "Inga publikationer.");
regGS("Default Site Alias", "Förvalt sajtalias");
regGS("URL Type", "URL-typ");
regGS("Country<BR><SMALL>(click to edit)</SMALL>", "Land<BR><SMALL>(klicka för att ändra)</SMALL>");
regGS("Delete alias $1", "Radera alias $1");
regGS("Configure publication", "Konfigurera publikation");
regGS("You do not have the right to edit publication information.", "Du har inte rätt att redigera publikationsinformation.");
regGS("General attributes", "Generella attribut");
regGS("You do not have the right to change publication information.", "Du har inte rätt att ändra publikationsinformation.");
regGS("The publication information could not be updated.", "Publikationsinformationen kunde inte uppdateras.");
regGS("You do not have the right to delete publications.", "Du har inte rätt att radera publikationer.");
regGS("Are you sure you want to delete the publication $1?", "Är du säker att du vill radera publikationen $1?");
regGS("Deleting publication", "Raderar publikation");
regGS("There are $1 subscription(s) left.", "Det finns $1 prenumeration(er) kvar.");
regGS("The publication $1 could not be deleted.", "Publikationen $1 kunde inte raderas.");
regGS("The publication could not be added.", "Publikationen kunde inte läggas till.");
regGS("You do not have the right to manage publications.", "Du har inte rätt att hantera publikationer.");
regGS("You must select a country.", "Du måste välja ett land.");
regGS("Default subscription time for $1 changed", "Grundprenumerationstid för $1 ändrad");
regGS("Subscription default time for $1 deleted", "Grundprenumerationstiden för $1 raderad");
regGS("Add new alias", "Lägg till nytt alias");
regGS("Alias (click to edit)", "Alias (klicka för att redigera)");
regGS("Edit aliases", "Redigera aliasar");
regGS("Publication Aliases", "Publikationsaliasar");
regGS("Adding new alias", "Lägger till nytt alias");
regGS("The site alias $1 has been added to publication $2.", "Sajtaliaset $1 har lagts till till publikationen $2.");
regGS("The site alias $1 could not be added.", "Sajtaliaset $1 kunde inte läggas till.");
regGS("Another alias with the same name exists already.", "Ett annat alias med samma namn finns redan.");
regGS("Edit alias", "Redigera alias");
regGS("Editing alias", "Redigerar alias");
regGS("The site alias for publication $1 has been modified to $2.", "Sajtaliaset för publikationen $1 har ändrats till $2.");
regGS("The site alias $1 could not be modified.", "Sajtaliaset $1 kunde inte ändras.");
regGS("Are you sure you want to delete the alias $1?", "Är du säker att du vill radera sajtaliaset $1?");
regGS("Deleting alias", "Raderar alias");
regGS("The alias $1 could not be deleted.", "Aliaset $1 kunde inte raderas.");
regGS("The alias $1 has been deleted from publication $2.", "Aliaset $1 har raderats från publikationen $2.");
regGS("$1 is the default publication alias, it can not be deleted.", "$1 är grundpublikationsaliaset, det kan inte raderas.");
regGS("You do not have the right to add publications.", "Du har inte rätt att lägga till publikationer.");
regGS("There are $1 issue(s) left.", "Det finns $1 utgåva(or) kvar.");
regGS("Time Unit", "Tidsenhet");
regGS("Currency", "Valuta");
regGS("Edit languages", "Redigera språk");
regGS("Select the publication", "Välj publikation");
regGS("Name<BR><SMALL>(click to select the publication)</SMALL>", "Namn<BR><SMALL>(klicka för att välja publikation)</SMALL>");
?>
